// Item Data
datablock ItemData(USP45Item)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system
	
	// USP45 Item Properties
	shapeFile = "./USP45.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;
	
	//gui stuff
	uiName = "HK: USP.45";
	iconName = "./Icon_USP45";
	doColorShift = true;
	colorShiftColor = "0.32 0.32 0.32 1";

	 // Dynamic properties defined by the scripts
	image = USP45Image;
	canDrop = true;

    // Ohh! Here's the part where I actually did something :O
	RYG_Reloads = 1;		// This weapon can reload!
	RYG_ClipSize = 12;		// Max clip size for this weapon.
};

// Weapon Image
datablock ShapeBaseImageData(USP45Image)
{
	// USP45 Image properties
	shapeFile = "./USP45.dts";
	emap = true;

	// Specify mount point & offset for 3rd person, and eye offset
	// for first person rendering.
	mountPoint = 0;
	offset = "0 0 0";
	eyeOffset = 0; //"0.7 1.2 -0.5";
	rotation = eulerToMatrix( "0 0 0" );

	// When firing from a point offset from the eye, muzzle correction
	// will adjust the muzzle vector to point to the eye LOS point.
	// Since this weapon doesn't actually fire from the muzzle point,
	// we need to turn this off.  
	correctMuzzleVector = true;

	// Add the WeaponImage namespace as a parent, WeaponImage namespace
	// provides some hooks into the inventory system.
	className = "WeaponImage";

    // Projectile && Ammo.
    item = USP45Item;
	ammo = " ";
    projectile = gunProjectile;
    projectileType = Projectile;

    casing = GunShellDebris;
    shellExitDir        = "1.0 0.1 1.0";
    shellExitOffset     = "0 0 0";
    shellExitVariance   = 10.0;	
    shellVelocity       = 5.0;

    //melee particles shoot from eye node for consistancy
    melee = false;
    //raise your arm up or not
    armReady = true;
	
	doColorShift = true;
    colorShiftColor = USP45Item.colorShiftColor; 

	// Rykuta's stuffings, THERE ARE A LOT, enjoy editing these.
	RYG_Support = 1;
	
    // Accuracy and recoil, biggest chunk.
	RYG_Accuracy = 0.00005;		// First bullet's accuracy.
	RYG_RecoilAdd = 0.00035;	// Amount of spread added per shot under time.
	RYG_RecoilSub = 0.001;		// Amount of spread reduced when gun has stopped spam firing.
	RYG_RecoilTick = 300;		// Delay between each shot required for the recoil to be reduced.
	RYG_MovementPer = 125;		// Percent of recoil generated due to movement. (If currenlty moving)
	RYG_CrouchPer = 75;      	// Percent of recoil generated while player is crouching. Does not stack with bipod. (Bipod has priority)
	RYG_MoveTimeout = 150;   	// Delay between last time moving and full recovery from moving.
	RYG_MaxRecoil = 0.003;		// Maximum recoil can reach.
	RYG_Oversight = 0.001;		// Animation becomes more aggressive after this recoil is reached.
	
    // Damage related stuff, yey :D
	RYG_MaxDmg = 11;		// Max damage at optimum Range.
	RYG_MinDmg = 6;			// Min damage at worst range.
	RYG_FalloffMax = 45;	// Range when bullet is at lowest damage. (In TorqueUnits)
	RYG_FalloffMin = 15;	// Range before bullet starts to lose damage. (In TorqueUnits)
	RYG_Headshot = 1.5;		// Multiplier for head damage.
	
    // Bipods, pistols do not have.
	RYG_Bipod = 0;			// Gives the weapon the ability to utilize a bipod.
	
    // If you like this reloading system :D
	RYG_BoltSound = PistolBoltSound;			// Sound name for bolt pull.
	RYG_ClipInSound = PistolInSound;			// Clip In Sound Name.
	RYG_ClipOutSound = PistolOutSound;			// Clip Out Sound Name.
   
    // Images have a state system which controls how the animations
    // are run, which sounds are played, script callbacks, etc. This
    // state system is downloaded to the client so that clients can
    // predict state changes and animate accordingly.  The following
    // system supports Gun ready->fire->reload transitions as
    // well as a no-ammo->dryfire idle state.
    raycastWeaponRange = 60; //varies               // Range is the max the bullet can hit, I'm not quite sure why Spacey put the "varies" word by it, because really, it doesn't.
	raycastWeaponTargets =
        $TypeMasks::PlayerObjectType |    //AI/Players
        $TypeMasks::StaticObjectType |    //Static Shapes
        $TypeMasks::TerrainObjectType |    //Terrain
        $TypeMasks::VehicleObjectType |    //Terrain
        $TypeMasks::FXBrickObjectType;    //Bricks
    raycastExplosionProjectile = GunProjectile;
    raycastExplosionBrickSound = bulletHitSound;
    raycastExplosionPlayerSound = bulletHitSound;
    raycastDirectDamage = 3;                        // Bot Damage
    raycastDirectDamageType = $DamageType::USP45;   
    raycastSpreadAmt = 0.00075; //varies            // This value is used by bots, not the player.
    raycastSpreadCount = 1;                         // Shotguns will have more than 1
    raycastTracerProjectile = TacticalSTracerProjectile;
    raycastFromMuzzle = true;
    raycastImpactImpulse = 10;
   

	// Main gun functionality  - - - - - - - - - - - - - - - - - - - - - - - - - - -
	stateName[0]                     	= "Activate";
	stateTimeoutValue[0]             	= 0.15;
	stateTransitionOnTimeout[0]       	= "LoadCheckA";
	StateSequence[0]					= "use";
	StateSound[0]						= "SmallDrawSound";
	StateScript[0]						= "onMount";
	
	stateName[1]                     	= "Ready";
	stateTransitionOnNoAmmo[1]       	= "Reload";
	stateTransitionOnTriggerDown[1]  	= "Fire";
	stateAllowImageChange[1]         	= true;
	stateScript[1]						= "onReady";

	stateName[2]                    	= "Fire";
	stateTransitionOnTimeout[2]     	= "Smoke";
	stateTimeoutValue[2]            	= 0.05;
	stateFire[2]                    	= true;
	stateAllowImageChange[2]        	= false;
	stateSequence[2]                	= "fire";
	stateScript[2]                  	= "onFire";
	stateEjectShell[2]       	  		= true;
	stateEmitter[2]						= gunFlashEmitter;
	stateEmitterTime[2]					= 0.05;
	stateEmitterNode[2]					= "muzzleNode";
	stateWaitForTimeout[2]				= true;
	StateSequence[2]					= "fire";
	stateSound[2]						= USPFireSound;

	stateName[3] 						= "Smoke";
	stateEmitter[3]						= gunSmokeEmitter;
	stateEmitterTime[3]					= 0.2;
	stateEmitterNode[3]					= "muzzleNode";
	stateTimeoutValue[3]				= 0.01;
	stateTransitionOnTimeout[3]			= "WaitForTriggerUp";
	
	stateName[8]						= "WaitForTriggerUp";
	stateScript[8]						= "WaitForTriggerUp";
	stateTransitionOnTriggerUp[8]		= "LoadCheckA";

	// Reload checks  - - - - - - - - - - - - - - - - - - - - - - - - - - -
	
	stateName[6]						= "LoadCheckA";
	stateScript[6]						= "onLoadCheck";
	stateTimeoutValue[6]				= 0.01;
	stateTransitionOnTimeout[6]			= "LoadCheckB";
	
	stateName[7]						= "LoadCheckB";
	stateTransitionOnAmmo[7]			= "Ready";
	stateTransitionOnNoAmmo[7]			= "NoRoundsLeftA";
	
	// No Rounds Left States - - - - - - - - - - - - - - - - - - - - - - - -
	// This was an intesting way to have a "dry-fire" system if weapons are without ammo, requiring the player to hit the light key to reload.
	stateName[9]						= "NoRoundsLeftA";
	stateScript[9]						= "NoRoundsLeft";
	stateTimeoutValue[9]				= 0.01;
	stateTransitionOnTimeout[9]			= "NoRoundsLeftB";
	
	stateName[10]						= "NoRoundsLeftB";
	stateTimeoutValue[10]				= 0.01;
	stateTransitionOnNoAmmo[10]			= "ReloadFull";
	stateTransitionOnTriggerDown[10]	= "NoRoundsLeftC";
	
	stateName[11]						= "NoRoundsLeftC";
	stateScript[11]						= "BlankFire";
	stateTimeoutValue[11]				= 0.01;
	stateTransitionOnTriggerUp[11]		= "NoRoundsLeftB";
	
	// Reloads - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	// Includes two sets of states, one for a full reload and the other for a half-reload.
	// Regular Reload
	stateName[12]						= "Reload";
	stateScript[12]						= "OnClipRemoved";
	stateTimeoutValue[12]				= 0.75;
	stateTransitionOnTimeout[12]     	= "InsertClipA";
	stateWaitForTimeout[12]				= true;
	StateSequence[12]					= "reload";
	
	stateName[13]						= "InsertClipA";
	stateScript[13]						= "OnClipInserted";
	stateTimeoutValue[13]				= 0.6;
	stateTransitionOnTimeout[13]     	= "ReloadFinish";
	stateWaitForTimeout[13]				= true;

	// Full Reload
	stateName[14]						= "ReloadFull";
	stateScript[14]						= "OnClipRemoved";
	stateTimeoutValue[14]				= 0.75;
	stateTransitionOnTimeout[14]     	= "InsertClipB";
	stateWaitForTimeout[14]				= true;

	stateName[15]						= "InsertClipB";
	stateScript[15]						= "OnClipInserted";
	stateTimeoutValue[15]				= 0.6;
	stateTransitionOnTimeout[15]     	= "GunBolt";
	stateWaitForTimeout[15]				= true;

	stateName[16]						= "GunBolt";
	stateScript[16]						= "onGunBolt";
	stateTimeoutValue[16]				= 0.5;
	stateTransitionOnTimeout[16]     	= "ReloadFinish";
	stateWaitForTimeout[16]				= true;

	// Finish reloading
	stateName[17]						= "ReloadFinish";
	stateScript[17]						= "OnGunReloadFinished";
	stateTimeoutValue[17]				= 0.01;
	stateTransitionOnTimeout[17]     	= "Ready";
	stateWaitForTimeout[17]				= true;
};